from sspo_db.config.base import Entity
from sqlalchemy import Column ,ForeignKey, Integer, String
from sqlalchemy.orm import relationship
from sqlalchemy_utils import EmailType

class Person (Entity):
    is_instance_of = "eo.person"    
    __tablename__ = "person"
    
    email = Column(EmailType)
    type = Column(String(50))
    
    organization_id = Column(Integer, ForeignKey('organization.id'))
    organization = relationship("Organization", back_populates="people")

    __mapper_args__ = {
        'polymorphic_identity':'person',
        'polymorphic_on':type
    }

class TeamMember(Person):
    is_instance_of = "eo.team_member"
    __tablename__ = "team_member"
    
    id = Column(Integer, ForeignKey('person.id'), primary_key=True)
    
    team_id = Column(Integer, ForeignKey('team.id'))
    team = relationship("Team",back_populates="team_members")

    team_role = Column(String(200), nullable=False)

    __mapper_args__ = {
        'polymorphic_identity':'team_member',
    }


from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from sspo_db.model.activity.models import *
from sspo_db.service.base_service import BaseService

class ScrumDevelopmentTaskService(BaseService):
    def __init__(self):
        super(ScrumDevelopmentTaskService,self).__init__(ScrumDevelopmentTask)

class ScrumIntentedDevelopmentTaskService(BaseService):
    def __init__(self):
        super(ScrumIntentedDevelopmentTaskService,self).__init__(ScrumIntentedDevelopmentTask)

class ScrumPerformedDevelopmentTaskService(BaseService):
    def __init__(self):
        super(ScrumPerformedDevelopmentTaskService,self).__init__(ScrumPerformedDevelopmentTask)




from sqlalchemy import create_engine
from sqlalchemy.orm import sessionmaker
from sspo_db.model.artifact.models import *
from sspo_db.service.base_service import BaseService

class ProductBacklogService(BaseService):
    def __init__(self):
        super(ProductBacklogService,self).__init__(ProductBacklog)

class UserStoryService(BaseService):
    def __init__(self):
        super(UserStoryService,self).__init__(UserStory)

class EpicService(BaseService):
    def __init__(self):
        super(EpicService,self).__init__(Epic)

class AtomicUserStoryService(BaseService):
    def __init__(self):
        super(AtomicUserStoryService,self).__init__(AtomicUserStory)

class SprintBacklogService(BaseService):
    def __init__(self):
        super(SprintBacklogService,self).__init__(SprintBacklog)

class AcceptanceCriterionService(BaseService):
    def __init__(self):
        super(AcceptanceCriterionService,self).__init__(AcceptanceCriterion)

class NonFunctionalAcceptanceCriterionService(BaseService):
    def __init__(self):
        super(NonFunctionalAcceptanceCriterionService,self).__init__(NonFunctionalAcceptanceCriterion)

class FunctionalAcceptanceCriterionService(BaseService):
    def __init__(self):
        super(FunctionalAcceptanceCriterionService,self).__init__(FunctionalAcceptanceCriterion)


from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker

SQLALCHEMY_DATABASE_URI = "mysql+mysqlconnector://root:force1@localhost/sspo2_ontology"
engine = create_engine(SQLALCHEMY_DATABASE_URI, echo=True)
#engine = create_engine('sqlite:///sspo.db', echo=True)
session = sessionmaker(bind=engine)
session = session()
Base = declarative_base()

class Config():

    def create_database(self):
        Base.metadata.create_all(engine)




from setuptools import setup, find_packages
version = "2.1.0"
setup(
    name='sspo_db',  # Required
    version=version,  # Required
    author="Paulo Sergio dos Santo Junior",
    author_email="paulossjuniort@gmail.com",
    description="A lib to access SSPO DB",
 
    packages=find_packages(),
    
    install_requires=[
        'SQLAlchemy', 'SQLAlchemy-Utils', 'mysql-connector-python'
    ],

    classifiers=[
         "Programming Language :: Python :: 3",
         "License :: OSI Approved :: MIT License",
         "Operating System :: OS Independent",
     ],
    setup_requires=['wheel'],
    
)



from sspo_db.config.base import Entity
from sqlalchemy import Column ,ForeignKey, Integer, String, DateTime
from sqlalchemy.orm import relationship


class IntentedStakeholderParticipation(Entity):
    is_instance_of = "spo.stakeholder.person.intented.participation"
    __tablename__ = "intented_stakeholder_participation"

    team_member = Column(Integer, ForeignKey('team_member.id'))
    intented_activity = Column(Integer, ForeignKey('scrum_intented_development_task.id'))
    
    
class PerformedStakeholderParticipation(Entity):
    is_instance_of = "spo.stakeholder.person.performed.participation"
    __tablename__ = "performed_stakeholder_participation"

    performed_activity = Column(Integer, ForeignKey('scrum_performed_development_task.id'))
    caused_by = Column(Integer, ForeignKey('intented_stakeholder_participation.id'))


class PerformedFragmentParticipation(Entity):
    __tablename__ = "performed_fragment_participation"

    startDate = Column(DateTime)
    endDate = Column(DateTime)
    #cost = models.DecimalField(max_digits=6, decimal_places=2,blank=True,null=True)
    performedStakeholderParticipation = Column(Integer, ForeignKey('performed_stakeholder_participation.id'))

    